@@ -1,23 +1,21 @@
 """ Downloader for git.ir links """
+import sys
 import time
 import argparse
 from pathlib import Path
+from typing import List
 
 import requests
-from tqdm import tqdm
 from halo import Halo
+from tqdm import tqdm
 
 
-ROOT_PATH = Path(__file__).resolve().parents[1]
-
-links_path = ROOT_PATH / ".links.txt"
-
-
-def download_files(folder_title, LINKS, args: argparse.Namespace):
+def download_files(folder_title: str, LINKS: List[str], args: argparse.Namespace):
     """
     Download files when the given URL is parsed
     """
 
+    ROOT_PATH = Path.cwd()
     links_len = len(LINKS)
 
     if args.name:
@@ -28,8 +26,12 @@ def download_files(folder_title, LINKS, args: argparse.Namespace):
     # Create folder
     spinner = Halo(text="Creating folder", spinner="dots")
     spinner.start()
-
-    dir_path.mkdir()
+    try:
+        dir_path.mkdir()
+    except FileExistsError:
+        time.sleep(1)
+        print(f"\nFolder '{folder_title}' already exists " "\N{cross mark}")
+        sys.exit(1)
     spinner.stop_and_persist(symbol="✅".encode("utf-8"), text="Folder Created")
 
     print(f"Total files: {links_len}")
@@ -47,14 +49,15 @@ def download_files(folder_title, LINKS, args: argparse.Namespace):
         spinner.stop()
 
         file = url.split("/")[-1]
+        print(f"Current file: {file}")
 
         with open(dir_path / file, "wb") as f:
             with tqdm(
                 total=total_size,
-                desc=file,
+                desc="{:<5}".format("Progress"),
                 unit="B",
                 unit_scale=True,
-                bar_format="{l_bar}{bar:20}{r_bar}{bar:-10b}",
+                bar_format="{desc:>1.40}: {percentage:5.0f}%|{bar:40}{r_bar}{bar:-10b}",
             ) as pbar:
                 for chunk in r.iter_content(chunk_size=1024):
                     if chunk:
