@@ -1,15 +1,17 @@
 """ Parse URL and scrape relevant links. """
 import re
 import argparse
-from typing import List
+from typing import List, Tuple
 
 import requests
 from bs4 import BeautifulSoup
 
+from .utils.tidy_names import tidy_names
 
-def parse_url(args: argparse.Namespace) -> str:
+
+def parse_url(args: argparse.Namespace) -> Tuple[str, List]:
     """
-    Prase url and extract links
+    Parse url and extract links
     """
     url = args.link
 
@@ -30,4 +32,6 @@ def parse_url(args: argparse.Namespace) -> str:
     ):
         LINKS_STORE.append(link.get("href"))
 
-    return folder_title, LINKS_STORE
+    names = tidy_names(LINKS_STORE)
+
+    return folder_title, names
